View Source OpentelemetrySnowpack (OpentelemetrySnowpack v0.4.1)

OpentelemetrySnowpack uses Elixir telemetry handlers to create OpenTelemetry spans from Snowpack (Snowflake driver) query events.

Currently it supports Snowpack query events: start, stop, exception.

usage

Usage

Add :opentelemetry_snowpack to your dependencies:

def deps() do
  [
    {:snowpack, "~> 0.6.0"},
    {:opentelemetry_snowpack, "~> 0.1.0"}
  ]
end

Make sure you are using the latest version!

In your application start:

def start(_type, _args) do
  OpentelemetrySnowpack.setup()

  # ...
end

Link to this section Summary

Functions

Attaches the OpentelemetrySnowpack handler to your Snowpack events. This should be called from your application behaviour on startup.

Link to this section Functions

@spec setup(keyword()) :: :ok

Attaches the OpentelemetrySnowpack handler to your Snowpack events. This should be called from your application behaviour on startup.

Example:

OpentelemetrySnowpack.setup()